@@ -91,6 +91,10 @@ def interpolate(
     else:
         start = start
 
+    # Change minute granulatiry to match CDF granularity
+    if granularity.lower().endswith("m"):
+        granularity = granularity.lower().replace("m", "T")
+
     # Output timestamps for uniform time series
     timestamps = pd.date_range(start, end, freq=granularity)
 
